:orphan:

Example Gallery
===============

Some tutorials for this package are included in Jupyter (formerly IPython) Notebooks. Jupyter Notebooks and the IPython kernel are dependencies for viewing these notebooks interactively. If you'd like to just view a static representation of these notebooks, use NBViewer.

The notebooks are also hosted on [mybinder.org]() if you would like to try the
package using temporary notebooks. No installation is required.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Use a linear, logistic regression model to estimate the positive/negative effects of mutations....">

.. only:: html

    .. figure:: /gallery/images/thumb/sphx_glr_plot_nonlinear_regression_thumb.png

        :ref:`sphx_glr_gallery_plot_nonlinear_regression.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /gallery/plot_nonlinear_regression

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Estimate high-order epistatic coefficients in arbitrary genotype-phenotype maps. A linear epist...">

.. only:: html

    .. figure:: /gallery/images/thumb/sphx_glr_plot_linear_regression_thumb.png

        :ref:`sphx_glr_gallery_plot_linear_regression.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /gallery/plot_linear_regression

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Use a linear, logistic regression model to estimate the positive/negative effects of mutations....">

.. only:: html

    .. figure:: /gallery/images/thumb/sphx_glr_plot_logistic_regression_thumb.png

        :ref:`sphx_glr_gallery_plot_logistic_regression.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /gallery/plot_logistic_regression
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: gallery_python.zip <//Users/zsailer/Documents/research/projects/pkgs/epistasis/docs/gallery/gallery_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: gallery_jupyter.zip <//Users/zsailer/Documents/research/projects/pkgs/epistasis/docs/gallery/gallery_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
